@@ -24,8 +24,8 @@
    
    You should have received a copy of the GNU  General Public
    License along with this software; if not, write to the
-   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -88,6 +88,7 @@ libpolyxmass_config_get_user_polyxmass_config_dir (void)
 	     _("%s@%d: failed to create directory: '%s' "
 	       "with error: '%s'\n"),
 	     __FILE__, __LINE__, confdir, strerror (errno));
+      g_free (confdir);
     }
   else
     {
@@ -335,7 +336,7 @@ libpolyxmass_config_get_user_polchem_defs_atom_defs_dic_dir (void)
 
   /* 
      Get the directory where all the atom definition catalogue files
-     are located for the user.
+     are located for the user. This directory name is allocated.
   */
   config_dir = libpolyxmass_config_get_user_polyxmass_config_dir ();
   
@@ -361,6 +362,8 @@ libpolyxmass_config_get_user_polchem_defs_atom_defs_dic_dir (void)
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
 	     _("%s@%d: catalogue directory not found: '%s'\n"),
 	     __FILE__, __LINE__, catalogue_dir);
+
+      g_free (catalogue_dir);
       
       return NULL;
     }
