@@ -24,8 +24,8 @@
    
    You should have received a copy of the GNU  General Public
    License along with this software; if not, write to the
-   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "pxmchem-masscalc.h"
@@ -404,7 +404,7 @@ pxmchem_masscalc_polymer_account_left_end_modif (PxmPolymer *polymer,
 				  NULL,
 				  "LEFT_END_MODIF",
 				  NULL,
-				  PXM_UNDEF_PROP_CMP);
+				  PXM_CMP_NO_DEEP);
   if (prop == NULL)
     return TRUE;
   
@@ -440,7 +440,7 @@ pxmchem_masscalc_polymer_account_right_end_modif (PxmPolymer *polymer,
 				  NULL,
 				  "RIGHT_END_MODIF",
 				  NULL,
-				  PXM_UNDEF_PROP_CMP);
+				  PXM_CMP_NO_DEEP);
   if (prop == NULL)
     return TRUE;
   
